<template>
      <!-- <MenuReaction v-if="isShowReaction && showEmoji && status !== 'failed'" :id="id" :is-seller="isSeller" @onSuccess="handleReactionSuccess" @onActive="handleOnActive"/> -->
    <div class="cursor-pointer pb-1 border-b" @click="openURL(object?.referral?.source_url ?? null)">
      <div class="relative rounded-sm  overflow-hidden block mb-2" style="border-radius: 0.7rem !important;">

        <div class="flex gap-3 justify-between">
          <div class="relative block w-28 overflow-hidden aspect-square field-content">
            <img v-if="object?.referral?.image_url" class="absolute left-1/2 top-1/2 transform -translate-x-1/2 -translate-y-1/2 w-auto h-auto m-auto min-w-full min-h-full" @error="imageLoadError" :src="object?.referral?.image_url ?? null" draggable="false" />
            <svg v-else xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" opacity="0.7">
                <rect width="256" height="256" fill="none"/>
                <polygon points="160 112 112 80 112 144 160 112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="16" opacity="0.7"/>
                <rect x="32" y="48" width="192" height="128" rx="8" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="16" opacity="0.7"/>
                <line x1="32" y1="208" x2="224" y2="208" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="16" opacity="0.7"/>
            </svg>
          </div>
          <div class="relative block p-2 w-full overflow-hidden bg-scheme-primary bg-opacity-5">
            <span class="block font-semibold text-scheme-primary">{{object?.referral?.headline ?? null}}</span>
            <span v-if="general.chatTab == 'tiktok'" class="whitespace-nowrap relative block overflow-hidden text-ellipsis text-gray-400" v-html="object?.referral?.source_id ?? null"></span>
            <span class="whitespace-nowrap relative block overflow-hidden text-ellipsis text-gray-400" v-html="object?.referral?.body ?? null"></span>
            <span class="whitespace-nowrap relative block overflow-hidden text-ellipsis text-gray-400 italic" v-html="object?.referral?.source_url ?? null"></span>
          </div>
        </div>
      </div>
    </div>

    <!-- <ReactionIcon :reaction-list="reactionArr"/> -->
    <span v-html="message" class="overflow-hidden relative block break-words pt-1"></span>
    <FailedSendMessage v-if="isSeller && status ==='failed'" :message="wa_error_message"/>

    <!-- <MenuChatBubble v-if="isShowMenuChat" :is-seller="isSeller" :message="message" :id="id" :chat_type="chatType"/> -->

    <div v-if="is_forwarded === 1"
          class="absolute  -top-8 gap-1 rounded-tl-xl rounded-tr-xl left-0 block w-full  ">
      <div class="relative flex py-2 items-center">
        <svg xmlns="http://www.w3.org/2000/svg" class="w-5 h-5 fill-current text-gray-400"
              viewBox="0 0 24 24">
          <path d="M21,12L14,5V9C7,10 4,15 3,20C5.5,16.5 9,14.9 14,14.9V19L21,12Z"/>
        </svg>
        <span class="italic text-gray-400">Forwarded</span>
      </div>
    </div>
    <div :class="`relative flex items-end gap-5 ${assignee ? 'justify-between' : 'justify-end'}` ">
      <div v-if="assignee"
            class="flex items-center gap-2 whitespace-nowrap  rounded-full py-1 px-2 bottom-1 text-xs bg-white text-primary text-right select-none">
        <span class="w-2 h-2 bg-scheme-primary rounded-full"></span>
        <span>{{ assignee.full_name }}</span>
      </div>
      <div class="flex gap-1 items-center justify-end">
        <span class="block  text-xs text-gray-600 text-right select-none">{{ date }}</span>
        <!-- loading -->
        <template v-if="isSeller && !isLoader">
          <IcMessageStatus :status="status"/>
        </template>
      </div>
    </div>
</template>

<script setup lang="ts">
import FailedSendMessage from "../Utility/FailedSendMessage.vue";
import IcMessageStatus from "../Icon/IcMessageStatus.vue";
import {onMounted, ref, watch} from "vue";
import MenuChatBubble from "../Menu/MenuChatBubble.vue";
import MenuReaction from "../../components/Menu/MenuReaction.vue";
import {useChatListStore} from "../../stores/chat_list";
import {useGeneralStore} from "../../stores/general";

interface Props {
  isSeller?: boolean
  isError?: boolean
  isLoading?: boolean
  isShowReaction?: boolean
  isShowMenuChat?: boolean
  status?: string
  isLoader?: boolean
  id?: bigint
  date?: string
  is_forwarded?: number
  reply_from_id?: string | number
  message?: string
  wa_error_message?: string
  chatType?: string
  assignee?: {
    full_name?: string
  }
  object?: any
  reactions?: any
}

let props = withDefaults(defineProps<Props>(), {
  isSeller: false,
  isError: false,
  isShowReaction: true,
  isShowMenuChat: true,
  is_forwarded: 0,
  isLoader: false,
  isLoading: false,
  date: null,
  id: null,
  status: null,
  assignee: null,
  chatType: null,
  message: null,
  wa_error_message: null,
  reply_from_id: null,
  reactions: null,
  object: {
    replied_message: {
      message: null,
      name: null,
      type: null,
      object: null,
    },
    referral: {
      chat_id: null,
      source_url: null,
      source_id: null,
      source_type: null,
      body: null,
      headline: null,
      media_type: null,
      image_url: null,
      ctwa_clid: null,
    }
  },
});

const chat = useChatListStore()
const general = useGeneralStore()
const showEmoji = ref(false)
const emojiActive = ref(false)
const reactionArr = ref([])

const handleReactionSuccess = (emojiString: any) => {
  let type_chat = general.chatTab
  let platform = ''

  if(general.chatTab === 'instagram'){
    type_chat = 'instagram'

    if(chat.selectedChatType === 'instagram'){
      platform = 'instagram'
    }
    
    if(chat.selectedChatType === 'facebook'){
      platform = 'page'
    }
  }

  chat.sendEmoji(chat.selectedChat, {
    to: chat?.detail?.customer?.phone,
    chat_id: props.id,
    emoji: emojiString,
    platform: platform
  },type_chat).then((resp) => {
    if (resp.code === 200) {
      const currentReaction = reactionArr.value.findIndex((rc) => rc.chat_id === props.id && rc.from_chat_user_id === chat.selectedChat)
      if (currentReaction == -1 && reactionArr.value.length == 0) {
        reactionArr.value.push({
          chat_id : props?.id,
          from_chat_user_id: chat.selectedChat,
          value: emojiString
        })
      } else {

        reactionArr.value.splice(currentReaction,1, {
          chat_id : props?.id,
          from_chat_user_id: chat.selectedChat,
          value: emojiString
        })
      }
    } else {
      console.log("400")
    }
  })
}

const openURL= (url) => {
  window.open(url,'_blank')
}

const handleOnActive= (event) => {
  emojiActive.value = event
}

const imageLoadError= (event) => {
    event.target.style = "display:none"
}


onMounted(() => {
  reactionArr.value = props.reactions
})

watch(() => props.reactions, (val) => {
  reactionArr.value = val
})


</script>


<style>
.field-content img {
  width: 100%;
  height: 5em;
  object-fit: cover;
}
</style>